==> huaweicloudsdkedgesec-3.1.129-py2.py3-none-any.whl: huaweicloudsdkedgesec/v2/model/show_http_block_trust_ip_rules_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowHttpBlockTrustIpRulesResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'items': 'list[ShowHttpBlockTrustIpRuleResponseBody]',
        'size': 'int'
    }

    attribute_map = {
        'total': 'total',
        'items': 'items',
        'size': 'size'
    }

    def __init__(self, total=None, items=None, size=None):
        """ShowHttpBlockTrustIpRulesResponse

        The model defined in huaweicloud sdk

        :param total: 策略下防护规则数量
        :type total: int
        :param items: 防护规则列表
        :type items: list[:class:`huaweicloudsdkedgesec.v2.ShowHttpBlockTrustIpRuleResponseBody`]
        :param size: 防护规则下IP/IP段数量
        :type size: int
        """
        
        super(ShowHttpBlockTrustIpRulesResponse, self).__init__()

        self._total = None
        self._items = None
        self._size = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if items is not None:
            self.items = items
        if size is not None:
            self.size = size

    @property
    def total(self):
        """Gets the total of this ShowHttpBlockTrustIpRulesResponse.

        策略下防护规则数量

        :return: The total of this ShowHttpBlockTrustIpRulesResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ShowHttpBlockTrustIpRulesResponse.

        策略下防护规则数量

        :param total: The total of this ShowHttpBlockTrustIpRulesResponse.
        :type total: int
        """
        self._total = total

    @property
    def items(self):
        """Gets the items of this ShowHttpBlockTrustIpRulesResponse.

        防护规则列表

        :return: The items of this ShowHttpBlockTrustIpRulesResponse.
        :rtype: list[:class:`huaweicloudsdkedgesec.v2.ShowHttpBlockTrustIpRuleResponseBody`]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this ShowHttpBlockTrustIpRulesResponse.

        防护规则列表

        :param items: The items of this ShowHttpBlockTrustIpRulesResponse.
        :type items: list[:class:`huaweicloudsdkedgesec.v2.ShowHttpBlockTrustIpRuleResponseBody`]
        """
        self._items = items

    @property
    def size(self):
        """Gets the size of this ShowHttpBlockTrustIpRulesResponse.

        防护规则下IP/IP段数量

        :return: The size of this ShowHttpBlockTrustIpRulesResponse.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this ShowHttpBlockTrustIpRulesResponse.

        防护规则下IP/IP段数量

        :param size: The size of this ShowHttpBlockTrustIpRulesResponse.
        :type size: int
        """
        self._size = size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowHttpBlockTrustIpRulesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkedgesec-3.1.151-py2.py3-none-any.whl: huaweicloudsdkedgesec/v2/model/show_http_block_trust_ip_rules_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowHttpBlockTrustIpRulesResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'items': 'list[ShowHttpBlockTrustIpRuleResponseBody]',
        'size': 'int'
    }

    attribute_map = {
        'total': 'total',
        'items': 'items',
        'size': 'size'
    }

    def __init__(self, total=None, items=None, size=None):
        r"""ShowHttpBlockTrustIpRulesResponse

        The model defined in huaweicloud sdk

        :param total: 策略下防护规则数量
        :type total: int
        :param items: 防护规则列表
        :type items: list[:class:`huaweicloudsdkedgesec.v2.ShowHttpBlockTrustIpRuleResponseBody`]
        :param size: 防护规则下IP/IP段数量
        :type size: int
        """
        
        super(ShowHttpBlockTrustIpRulesResponse, self).__init__()

        self._total = None
        self._items = None
        self._size = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if items is not None:
            self.items = items
        if size is not None:
            self.size = size

    @property
    def total(self):
        r"""Gets the total of this ShowHttpBlockTrustIpRulesResponse.

        策略下防护规则数量

        :return: The total of this ShowHttpBlockTrustIpRulesResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        r"""Sets the total of this ShowHttpBlockTrustIpRulesResponse.

        策略下防护规则数量

        :param total: The total of this ShowHttpBlockTrustIpRulesResponse.
        :type total: int
        """
        self._total = total

    @property
    def items(self):
        r"""Gets the items of this ShowHttpBlockTrustIpRulesResponse.

        防护规则列表

        :return: The items of this ShowHttpBlockTrustIpRulesResponse.
        :rtype: list[:class:`huaweicloudsdkedgesec.v2.ShowHttpBlockTrustIpRuleResponseBody`]
        """
        return self._items

    @items.setter
    def items(self, items):
        r"""Sets the items of this ShowHttpBlockTrustIpRulesResponse.

        防护规则列表

        :param items: The items of this ShowHttpBlockTrustIpRulesResponse.
        :type items: list[:class:`huaweicloudsdkedgesec.v2.ShowHttpBlockTrustIpRuleResponseBody`]
        """
        self._items = items

    @property
    def size(self):
        r"""Gets the size of this ShowHttpBlockTrustIpRulesResponse.

        防护规则下IP/IP段数量

        :return: The size of this ShowHttpBlockTrustIpRulesResponse.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        r"""Sets the size of this ShowHttpBlockTrustIpRulesResponse.

        防护规则下IP/IP段数量

        :param size: The size of this ShowHttpBlockTrustIpRulesResponse.
        :type size: int
        """
        self._size = size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowHttpBlockTrustIpRulesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
